Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/cap1188_simpletest.py
    :caption: examples/cap1188_simpletest.py
    :linenos:

Advance test
------------

This example show the new feature included in the library allowing the possibilite the
configure the averaging, cycle and sample. For reference please see Sensor Datasheet.

.. literalinclude:: ../examples/cap1188_advancedtest.py
    :caption: examples/cap1188_advancedtest.py
    :linenos:
